@@ -1,5 +1,28 @@
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
 
+// ref.) https://en.wikipedia.org/wiki/Memory_ordering
+fn memory_barrier(_arg: &mut [Vec<u8>]) {
+    #[cfg(target_feature = "sse2")]
+    {
+        #[cfg(target_arch = "x86")]
+        use std::arch::x86 as mmx;
+        #[cfg(target_arch = "x86_64")]
+        use std::arch::x86_64 as mmx;
+
+        unsafe { mmx::_mm_mfence() };
+    }
+    /*
+    #[cfg(target_arch = "arm")]
+    {
+        unsafe { core::arch::arm::__dmb(_arg) };
+    }
+    #[cfg(target_arch = "aarch64")]
+    {
+        unsafe { core::arch::aarch64::__dmb(_arg) };
+    }
+    */
+}
+
 #[inline(never)]
 fn process_std_memset(texts: &mut [Vec<u8>], pat_u8: u8) {
     for i in 0..texts.len() {
@@ -48,21 +71,25 @@ fn criterion_benchmark(c: &mut Criterion) {
     c.bench_function("std_memset", |b| {
         b.iter(|| {
             process_std_memset(black_box(&mut v), black_box(pat_u8));
+            memory_barrier(&mut v);
         })
     });
     c.bench_function("memx_memset", |b| {
         b.iter(|| {
             process_memx_memset(black_box(&mut v), black_box(pat_u8));
+            memory_barrier(&mut v);
         })
     });
     c.bench_function("memx_memset_basic", |b| {
         b.iter(|| {
             process_memx_memset_basic(black_box(&mut v), black_box(pat_u8));
+            memory_barrier(&mut v);
         })
     });
     c.bench_function("memx_memset_libc", |b| {
         b.iter(|| {
             process_memx_memset_libc(black_box(&mut v), black_box(pat_u8));
+            memory_barrier(&mut v);
         })
     });
 }
