@@ -8,10 +8,16 @@ pub mod mem;
 pub struct RangeError;
 
 pub fn memchr(buf: &[u8], c: u8) -> Option<usize> {
-    #[cfg(any(target_arch = "x86_64", target_arch = "x86"))]
+    #[cfg(all(
+        any(target_arch = "x86_64", target_arch = "x86"),
+        any(target_feature = "sse2", target_feature = "avx")
+    ))]
     let r = arch::x86::_memchr_impl(buf, c);
     //
-    #[cfg(not(any(target_arch = "x86_64", target_arch = "x86",)))]
+    #[cfg(any(
+        not(any(target_arch = "x86_64", target_arch = "x86",)),
+        not(any(target_feature = "sse2", target_feature = "avx"))
+    ))]
     let r = mem::_memchr_impl(buf, c);
     //
     r
@@ -24,15 +30,17 @@ pub fn memcmp(a: &[u8], b: &[u8]) -> Ordering {
 }
 
 pub fn memcpy(dst: &mut [u8], src: &[u8]) -> Result<(), RangeError> {
-    #[cfg(any(target_arch = "x86_64", target_arch = "x86"))]
+    #[cfg(all(
+        any(target_arch = "x86_64", target_arch = "x86"),
+        any(target_feature = "sse2", target_feature = "avx")
+    ))]
     let r = arch::x86::_memcpy_impl(dst, src);
-    //
-    #[cfg(target_arch = "arm")]
+    #[cfg(any(
+        not(any(target_arch = "x86_64", target_arch = "x86",)),
+        not(any(target_feature = "sse2", target_feature = "avx"))
+    ))]
     let r = mem::_memcpy_impl(dst, src);
     //
-    #[cfg(not(any(target_arch = "x86_64", target_arch = "x86", target_arch = "arm")))]
-    let r = libc::_memcpy_impl(dst, src);
-    //
     r
 }
 
@@ -49,15 +57,17 @@ pub fn memmem(haystack: &[u8], needle: &[u8]) -> Option<usize> {
 }
 
 pub fn memset(buf: &mut [u8], c: u8, n: usize) -> Result<(), RangeError> {
-    #[cfg(any(target_arch = "x86_64", target_arch = "x86"))]
+    #[cfg(all(
+        any(target_arch = "x86_64", target_arch = "x86"),
+        any(target_feature = "sse2", target_feature = "avx")
+    ))]
     let r = arch::x86::_memset_impl(buf, c, n);
-    //
-    #[cfg(target_arch = "arm")]
+    #[cfg(any(
+        not(any(target_arch = "x86_64", target_arch = "x86",)),
+        not(any(target_feature = "sse2", target_feature = "avx"))
+    ))]
     let r = mem::_memset_impl(buf, c, n);
     //
-    #[cfg(not(any(target_arch = "x86_64", target_arch = "x86", target_arch = "arm")))]
-    let r = libc::_memset_impl(buf, c, n);
-    //
     r
 }
 
