@@ -1,11 +1,19 @@
 mod mem_chr;
 pub(crate) use mem_chr::_memchr_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_chr::_memchr_remaining_15_bytes_impl;
 
 mod mem_cmp;
 pub(crate) use mem_cmp::_memcmp_impl;
 
 mod mem_cpy;
 pub(crate) use mem_cpy::_memcpy_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_cpy::_memcpy_remaining_15_bytes_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_cpy::_memcpy_remaining_3_bytes_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_cpy::_memcpy_remaining_7_bytes_impl;
 
 mod mem_eq;
 pub(crate) use mem_eq::_memeq_impl;
@@ -15,9 +23,13 @@ pub(crate) use mem_mem::_memmem_impl;
 
 mod mem_set;
 pub(crate) use mem_set::_memset_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_set::_memset_remaining_15_bytes_impl;
+#[allow(unused_imports)]
+pub(crate) use mem_set::_start_set_64;
 
-use std::cmp::Ordering;
 use super::RangeError;
+use std::cmp::Ordering;
 
 pub fn memchr_basic(buf: &[u8], c: u8) -> Option<usize> {
     crate::mem::_memchr_impl(buf, c)
